@@ -37,10 +37,8 @@
 #include <gdk/gdkkeysyms.h>
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
-#include <libmate-desktop/mate-aboutdialog.h>
 
 #include "egg-debug.h"
-#include "egg-dbus-monitor.h"
 #include "gpm-common.h"
 
 #define GPM_TYPE_BRIGHTNESS_APPLET		(gpm_brightness_applet_get_type ())
@@ -63,7 +61,7 @@ typedef struct{
 	/* connection to g-p-m */
 	DBusGProxy *proxy;
 	DBusGConnection *connection;
-	EggDbusMonitor *monitor;
+	guint bus_watch_id;
 	guint level;
 	/* a cache for panel size */
 	gint size;
@@ -532,7 +530,11 @@ gpm_applet_key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
 			gdk_keyboard_ungrab (GDK_CURRENT_TIME);
 			gdk_pointer_ungrab (GDK_CURRENT_TIME);
 			gtk_grab_remove (GTK_WIDGET(applet));
+#if GTK_CHECK_VERSION (3, 0, 0)
+			gtk_widget_set_state_flags (GTK_WIDGET(applet), GTK_STATE_FLAG_NORMAL, TRUE);
+#else
 			gtk_widget_set_state (GTK_WIDGET(applet), GTK_STATE_NORMAL);
+#endif
 			gtk_widget_hide (applet->popup);
 			applet->popped = FALSE;
 			gpm_applet_draw_cb (applet);
@@ -902,7 +904,7 @@ gpm_applet_stop_scroll_events_cb (GtkWidget *widget, GdkEvent  *event)
 static void
 gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 {
-	MateAboutDialog *about;
+	GtkAboutDialog *about;
 
 	GdkPixbuf *logo =
 		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
@@ -914,6 +916,11 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 		"Richard Hughes <richard@hughsie.com>",
 		NULL
 	};
+
+	char copyright[] = \
+		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
+		"Copyright \xc2\xa9 2006 Benjamin Canou";
+
 	const char *documenters [] = {
 		NULL
 	};
@@ -938,17 +945,17 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 	license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
 				     _(license[2]), "\n\n", _(license[3]), "\n", NULL);
 
-	about = (MateAboutDialog*) mate_about_dialog_new ();
-	mate_about_dialog_set_program_name (about, GPM_BRIGHTNESS_APPLET_NAME);
-	mate_about_dialog_set_version (about, VERSION);
-	mate_about_dialog_set_copyright (about, _("Copyright \xc2\xa9 2006 Benjamin Canou"));
-	mate_about_dialog_set_comments (about, GPM_BRIGHTNESS_APPLET_DESC);
-	mate_about_dialog_set_authors (about, authors);
-	mate_about_dialog_set_documenters (about, documenters);
-	mate_about_dialog_set_translator_credits (about, translator_credits);
-	mate_about_dialog_set_logo (about, logo);
-	mate_about_dialog_set_license (about, license_trans);
-	mate_about_dialog_set_website (about, "http://www.mate-desktop.org/");
+	about = (GtkAboutDialog*) gtk_about_dialog_new ();
+	gtk_about_dialog_set_program_name (about, GPM_BRIGHTNESS_APPLET_NAME);
+	gtk_about_dialog_set_version (about, VERSION);
+	gtk_about_dialog_set_copyright (about, copyright);
+	gtk_about_dialog_set_comments (about, GPM_BRIGHTNESS_APPLET_DESC);
+	gtk_about_dialog_set_authors (about, authors);
+	gtk_about_dialog_set_documenters (about, documenters);
+	gtk_about_dialog_set_translator_credits (about, translator_credits);
+	gtk_about_dialog_set_logo (about, logo);
+	gtk_about_dialog_set_license (about, license_trans);
+	gtk_about_dialog_set_website (about, "http://www.mate-desktop.org/");
 
 	g_signal_connect (G_OBJECT(about), "response",
 			  G_CALLBACK(gtk_widget_destroy), NULL);
@@ -979,12 +986,9 @@ gpm_applet_destroy_cb (GtkWidget *widget)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(widget);
 
-	if (applet->monitor != NULL) {
-		g_object_unref (applet->monitor);
-	}
-	if (applet->icon != NULL) {
+	g_bus_unwatch_name (applet->bus_watch_id);
+	if (applet->icon != NULL)
 		g_object_unref (applet->icon);
-	}
 }
 
 /**
@@ -1065,25 +1069,30 @@ gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
 }
 
 /**
- * monitor_connection_cb:
- * @proxy: The dbus raw proxy
- * @status: The status of the service, where TRUE is connected
- * @screensaver: This class instance
+ * gpm_brightness_applet_name_appeared_cb:
  **/
 static void
-monitor_connection_cb (EggDbusMonitor           *monitor,
-		     gboolean	          status,
-		     GpmBrightnessApplet *applet)
+gpm_brightness_applet_name_appeared_cb (GDBusConnection *connection,
+					const gchar *name,
+					const gchar *name_owner,
+					GpmBrightnessApplet *applet)
 {
-	if (status) {
-		gpm_brightness_applet_dbus_connect (applet);
-		gpm_applet_update_tooltip (applet);
-		gpm_applet_draw_cb (applet);
-	} else {
-		gpm_brightness_applet_dbus_disconnect (applet);
-		gpm_applet_update_tooltip (applet);
-		gpm_applet_draw_cb (applet);
-	}
+	gpm_brightness_applet_dbus_connect (applet);
+	gpm_applet_update_tooltip (applet);
+	gpm_applet_draw_cb (applet);
+}
+
+/**
+ * gpm_brightness_applet_name_vanished_cb:
+ **/
+void
+gpm_brightness_applet_name_vanished_cb (GDBusConnection *connection,
+					 const gchar *name,
+					 GpmBrightnessApplet *applet)
+{
+	gpm_brightness_applet_dbus_disconnect (applet);
+	gpm_applet_update_tooltip (applet);
+	gpm_applet_draw_cb (applet);
 }
 
 /**
@@ -1109,12 +1118,14 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 
-	applet->monitor = egg_dbus_monitor_new ();
-	g_signal_connect (applet->monitor, "connection-changed",
-			  G_CALLBACK (monitor_connection_cb), applet);
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-	egg_dbus_monitor_assign (applet->monitor, connection, GPM_DBUS_SERVICE);
-	gpm_brightness_applet_dbus_connect (applet);
+	/* monitor the daemon */
+	applet->bus_watch_id =
+		g_bus_watch_name (G_BUS_TYPE_SESSION,
+				  GPM_DBUS_SERVICE,
+				  G_BUS_NAME_WATCHER_FLAGS_NONE,
+				  (GBusNameAppearedCallback) gpm_brightness_applet_name_appeared_cb,
+				  (GBusNameVanishedCallback) gpm_brightness_applet_name_vanished_cb,
+				  applet, NULL);
 
 	/* coldplug */
 	applet->call_worked = gpm_applet_get_brightness (applet);
