@@ -36,10 +36,8 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
-#include <libmate-desktop/mate-aboutdialog.h>
 
 #include "egg-debug.h"
-#include "egg-dbus-monitor.h"
 #include "gpm-common.h"
 
 #define GPM_TYPE_INHIBIT_APPLET		(gpm_inhibit_applet_get_type ())
@@ -59,7 +57,7 @@ typedef struct{
 	/* connection to g-p-m */
 	DBusGProxy *proxy;
 	DBusGConnection *connection;
-	EggDbusMonitor *monitor;
+	guint bus_watch_id;
 	guint level;
 	/* a cache for panel size */
 	gint size;
@@ -428,7 +426,7 @@ gpm_applet_click_cb (GpmInhibitApplet *applet, GdkEventButton *event)
 static void
 gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 {
-	MateAboutDialog *about;
+	GtkAboutDialog *about;
 
 	GdkPixbuf *logo =
 		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
@@ -440,6 +438,11 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 		"Richard Hughes <richard@hughsie.com>",
 		NULL
 	};
+
+	char copyright[] = \
+		"Copyright \xc2\xa9 2012-2016 MATE developers\n"
+		"Copyright \xc2\xa9 2006-2007 Richard Hughes";
+
 	const char *documenters [] = {
 		NULL
 	};
@@ -464,17 +467,17 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 	license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
 				     _(license[2]), "\n\n", _(license[3]), "\n", NULL);
 
-	about = (MateAboutDialog*) mate_about_dialog_new ();
-	mate_about_dialog_set_program_name (about, GPM_INHIBIT_APPLET_NAME);
-	mate_about_dialog_set_version (about, VERSION);
-	mate_about_dialog_set_copyright (about, _("Copyright \xc2\xa9 2006-2007 Richard Hughes"));
-	mate_about_dialog_set_comments (about, GPM_INHIBIT_APPLET_DESC);
-	mate_about_dialog_set_authors (about, authors);
-	mate_about_dialog_set_documenters (about, documenters);
-	mate_about_dialog_set_translator_credits (about, translator_credits);
-	mate_about_dialog_set_logo (about, logo);
-	mate_about_dialog_set_license (about, license_trans);
-	mate_about_dialog_set_website (about, "http://www.mate-desktop.org/");
+	about = (GtkAboutDialog*) gtk_about_dialog_new ();
+	gtk_about_dialog_set_program_name (about, GPM_INHIBIT_APPLET_NAME);
+	gtk_about_dialog_set_version (about, VERSION);
+	gtk_about_dialog_set_copyright (about, copyright);
+	gtk_about_dialog_set_comments (about, GPM_INHIBIT_APPLET_DESC);
+	gtk_about_dialog_set_authors (about, authors);
+	gtk_about_dialog_set_documenters (about, documenters);
+	gtk_about_dialog_set_translator_credits (about, translator_credits);
+	gtk_about_dialog_set_logo (about, logo);
+	gtk_about_dialog_set_license (about, license_trans);
+	gtk_about_dialog_set_website (about, "http://www.mate-desktop.org/");
 
 	g_signal_connect (G_OBJECT(about), "response",
 			  G_CALLBACK(gtk_widget_destroy), NULL);
@@ -505,12 +508,9 @@ gpm_applet_destroy_cb (GtkWidget *widget)
 {
 	GpmInhibitApplet *applet = GPM_INHIBIT_APPLET(widget);
 
-	if (applet->monitor != NULL) {
-		g_object_unref (applet->monitor);
-	}
-	if (applet->icon != NULL) {
+	g_bus_unwatch_name (applet->bus_watch_id);
+	if (applet->icon != NULL)
 		g_object_unref (applet->icon);
-	}
 }
 
 /**
@@ -578,27 +578,32 @@ gpm_inhibit_applet_dbus_disconnect (GpmInhibitApplet *applet)
 }
 
 /**
- * monitor_connection_cb:
- * @proxy: The dbus raw proxy
- * @status: The status of the service, where TRUE is connected
- * @screensaver: This class instance
+ * gpm_inhibit_applet_name_appeared_cb:
  **/
 static void
-monitor_connection_cb (EggDbusMonitor           *monitor,
-		     gboolean	          status,
-		     GpmInhibitApplet *applet)
+gpm_inhibit_applet_name_appeared_cb (GDBusConnection *connection,
+				     const gchar *name,
+				     const gchar *name_owner,
+				     GpmInhibitApplet *applet)
 {
-	if (status) {
-		gpm_inhibit_applet_dbus_connect (applet);
-		gpm_applet_update_tooltip (applet);
-		gpm_applet_get_icon (applet);
-		gpm_applet_draw_cb (applet);
-	} else {
-		gpm_inhibit_applet_dbus_disconnect (applet);
-		gpm_applet_update_tooltip (applet);
-		gpm_applet_get_icon (applet);
-		gpm_applet_draw_cb (applet);
-	}
+	gpm_inhibit_applet_dbus_connect (applet);
+	gpm_applet_update_tooltip (applet);
+	gpm_applet_get_icon (applet);
+	gpm_applet_draw_cb (applet);
+}
+
+/**
+ * gpm_inhibit_applet_name_vanished_cb:
+ **/
+void
+gpm_inhibit_applet_name_vanished_cb (GDBusConnection *connection,
+				     const gchar *name,
+				     GpmInhibitApplet *applet)
+{
+	gpm_inhibit_applet_dbus_disconnect (applet);
+	gpm_applet_update_tooltip (applet);
+	gpm_applet_get_icon (applet);
+	gpm_applet_draw_cb (applet);
 }
 
 /**
@@ -621,12 +626,14 @@ gpm_inhibit_applet_init (GpmInhibitApplet *applet)
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
-	applet->monitor = egg_dbus_monitor_new ();
-	g_signal_connect (applet->monitor, "connection-changed",
-			  G_CALLBACK (monitor_connection_cb), applet);
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-	egg_dbus_monitor_assign (applet->monitor, connection, GS_DBUS_SERVICE);
-	gpm_inhibit_applet_dbus_connect (applet);
+	/* monitor the daemon */
+	applet->bus_watch_id =
+		g_bus_watch_name (G_BUS_TYPE_SESSION,
+				  GS_DBUS_SERVICE,
+				  G_BUS_NAME_WATCHER_FLAGS_NONE,
+				  (GBusNameAppearedCallback) gpm_inhibit_applet_name_appeared_cb,
+				  (GBusNameVanishedCallback) gpm_inhibit_applet_name_vanished_cb,
+				  applet, NULL);
 
 	/* prepare */
 	mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet), MATE_PANEL_APPLET_EXPAND_MINOR);
